library(testthat)
#library(localScore)

test_check("localScore")
